@@ -21,7 +21,14 @@ def halfedges(F):
 
     Examples
     --------
-    TODO
+    ```python
+    # Sample mesh
+    v = np.array([[0.0,0.0],[1.0,0.0],[0.0,1.0]])
+    f = np.array([[0,1,2]],dtype=int)
+    # Call to halfedges
+    from gpytoolbox import halfedges
+    he = halfedges(v,f)
+    ```
     
     """
     
