@@ -29,7 +29,14 @@ def offset_surface(V,F,iso,grid_size=100):
 
     Examples
     --------
-    TO-DO
+    ```python
+    from gpytoolbox import read_mesh, normalize_points, offset_surface
+    # Read a mesh
+    v,f = read_mesh("test/unit_tests_data/armadillo.obj")
+    # Normalize the mesh
+    v = normalize_points(v)
+    u1,g1 = offset_surface(v,f,iso=0.05,grid_size=100)
+    ```
     """
 
 
@@ -38,6 +45,6 @@ def offset_surface(V,F,iso,grid_size=100):
     except:
         raise ImportError("Gpytoolbox cannot import its C++ binding.")
 
-    v, f = _offset_surface_cpp_impl(V,F.astype(np.int32),iso,grid_size)
+    v, f = _offset_surface_cpp_impl(V.astype(np.float64),F.astype(np.int32),iso,grid_size)
 
     return v,f
