@@ -27,7 +27,17 @@ def upper_envelope(V,T,D):
 
     Examples
     --------
-    TODO
+    ```python
+    # Build a tet mesh
+    V,T  = gpytoolbox.regular_cube_mesh(20)
+    # Build a soft label for each vertex
+    l = np.zeros((V.shape[0],2))
+    l[:,0] = np.linalg.norm(V,axis=1)
+    l[:,1] = 1.0 - l[:,0]
+    # Slice the mesh
+    U,G,LT = gpytoolbox.upper_envelope(V,T,l)
+    # U is the sliced mesh
+    ```
     """
 
     try:
@@ -35,6 +45,6 @@ def upper_envelope(V,T,D):
     except:
         raise ImportError("Gpytoolbox cannot import its C++ binding.")
 
-    ut, gt, lt = _upper_envelope_cpp_impl(V,T.astype(np.int32),D)
+    ut, gt, lt = _upper_envelope_cpp_impl(V.astype(np.float64),T.astype(np.int32),D.astype(np.float64))
 
     return ut, gt, lt
